#include <QtGui>
#include <QtOpenGL>
#include <QtSvg>

static const int LastSlideIdx = 11;

class Widget : public QWidget
{
    Q_OBJECT
public:
    Widget() :
        QWidget(),
        m_idx(1)
    {
        m_renderer = new QSvgRenderer(this);
        connect(m_renderer, SIGNAL(repaintNeeded()),
                SLOT(update()));
        m_renderer->load(currentSlide());
    }

protected:
    void paintEvent(QPaintEvent *e)
    {
        QPainter p(this);
        p.setRenderHint(QPainter::Antialiasing);

        m_renderer->render(&p);
    }
    void keyPressEvent(QKeyEvent *e)
    {
        switch (e->key()) {
        case Qt::Key_Backspace:
        case Qt::Key_Left:
            --m_idx;
            if (m_idx < 1)
                m_idx = 1;
            m_renderer->load(currentSlide());
            update();
            break;
        case Qt::Key_Enter:
        case Qt::Key_Return:
        case Qt::Key_Right:
            ++m_idx;
            if (m_idx > LastSlideIdx)
                m_idx = LastSlideIdx;
            m_renderer->load(currentSlide());
            update();
        }
    }

    QString currentSlide() const
    {
        return QString("slide%1.svg").arg(m_idx);
    }

    int m_idx;
    QSvgRenderer *m_renderer;
};

#include "main.moc"


int main(int argc, char **argv)
{
    QApplication app(argc, argv);

    Widget w;
    w.showFullScreen();

    return app.exec();
}
